@@ -1,16 +1,13 @@
 "ordiParseFormula" <-
     function (formula, data) 
 {
-    if (formula[[3]] == ".") {
-        point <- paste(names(data), collapse = "+")
-        formula <- update(formula, paste(". ~", point))
-    }
     Terms <- terms(formula, "Condition", data = data)
+    flapart <- fla <- formula <- formula(Terms, width.cutoff = 500)
     specdata <- formula[[2]]
     X <- eval(specdata, data, parent.frame())
     X <- as.matrix(X)
     indPartial <- attr(Terms, "specials")$Condition
-    Z <- NULL
+    mf <- Z <- NULL
     if (!is.null(indPartial)) {
         partterm <- attr(Terms, "variables")[[1 + indPartial]]
         Pterm <- deparse(partterm[[2]])
@@ -19,6 +16,7 @@
         Z <- model.matrix(P.formula, mf)
         formula <- update(formula, paste(".~.-", deparse(partterm, 
                                                          width.cutoff = 500)))
+        flapart <- update(formula, paste(". ~ . +", Pterm))
     }
     formula[[2]] <- NULL
     if (formula[[2]] == "1" || formula[[2]] == "0") 
@@ -28,8 +26,9 @@
         Y <- model.matrix(formula, mf)
         if (any(colnames(Y) == "(Intercept)")) {
             xint <- which(colnames(Y) == "(Intercept)")
-            Y <- Y[, -xint, drop=FALSE]
+            Y <- Y[, -xint, drop = FALSE]
         }
     }
-    list(X = X, Y = Y, Z = Z)
+    list(X = X, Y = Y, Z = Z, terms = terms(fla, width.cutoff = 500), 
+         terms.expand = terms(flapart, width.cutoff = 500), modelframe=mf)
 }
